==> copilot-24.9.0-sources.jar: com/vaadin/copilot/plugins/info/CopilotInfo.java <==
/*
 * Copyright 2000-2024 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.copilot.plugins.info;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import com.vaadin.copilot.CopilotVersion;
import com.vaadin.copilot.SpringBridge;
import com.vaadin.flow.internal.hilla.EndpointRequestUtil;
import com.vaadin.flow.server.Mode;
import com.vaadin.flow.server.Platform;
import com.vaadin.flow.server.VaadinServletContext;
import com.vaadin.flow.server.Version;
import com.vaadin.flow.server.startup.ApplicationConfiguration;

public class CopilotInfo {

    public record NameAndVersion(String name, String version) implements Serializable {
    }

    private final List<NameAndVersion> versions = new ArrayList<>();

    /** Creates a new instance. */
    public CopilotInfo(ApplicationConfiguration applicationConfiguration) {
        // The order here is the order shown in dev tools
        if (EndpointRequestUtil.isHillaAvailable()) {
            versions.add(new NameAndVersion("Hilla", fetchHillaVersion()));
        }
        versions.add(new NameAndVersion("Flow", Version.getFullVersion()));
        if (isVaadinAvailable()) {
            versions.add(new NameAndVersion("Vaadin", fetchVaadinVersion()));
        }

        if (SpringBridge.isSpringAvailable((VaadinServletContext) applicationConfiguration.getContext())) {
            SpringBridge.VersionInfo springVersions = SpringBridge.getVersionInfo();
            versions.add(new NameAndVersion("Spring Boot", springVersions.springBootVersion()));
            versions.add(new NameAndVersion("Spring", springVersions.springVersion()));
        }

        versions.add(new NameAndVersion("Copilot", CopilotVersion.getVersion()));

        String frontendHotswap = applicationConfiguration.getMode() == Mode.DEVELOPMENT_FRONTEND_LIVERELOAD
                ? "Enabled ⋅ Vite"
                : "Disabled ⋅ Pre-built Bundle";
        versions.add(new NameAndVersion("Frontend Hotswap", frontendHotswap));
        versions.add(new NameAndVersion("OS", fetchOperatingSystem()));
        versions.add(new NameAndVersion("Java", fetchJavaVersion()));
    }

    public static String fetchJavaVersion() {
        String vendor = System.getProperty("java.vendor");
        String version = System.getProperty("java.version");

        return vendor + " " + version;
    }

    public static String fetchOperatingSystem() {
        String arch = System.getProperty("os.arch");
        String name = System.getProperty("os.name");
        String version = System.getProperty("os.version");

        return arch + " " + name + " " + version;
    }

    public static String fetchVaadinVersion() {
        return isVaadinAvailable() ? Platform.getVaadinVersion().orElse("?") : "-";
    }

    public static String fetchHillaVersion() {
        return EndpointRequestUtil.isHillaAvailable() ? Platform.getHillaVersion().orElse("?") : "-";
    }

    public List<NameAndVersion> getVersions() {
        return versions;
    }

    private static boolean isVaadinAvailable() {
        return Thread.currentThread().getContextClassLoader()
                .getResource("META-INF/maven/com.vaadin/vaadin-core/pom.properties") != null;
    }
}

==> copilot-25.1-20260114.103516-69-sources.jar: com/vaadin/copilot/plugins/info/CopilotInfo.java <==
/*
 * Copyright 2000-2024 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.copilot.plugins.info;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import com.vaadin.copilot.CopilotVersion;
import com.vaadin.copilot.SpringBridge;
import com.vaadin.flow.internal.hilla.EndpointRequestUtil;
import com.vaadin.flow.server.Mode;
import com.vaadin.flow.server.Platform;
import com.vaadin.flow.server.Version;
import com.vaadin.flow.server.startup.ApplicationConfiguration;

public class CopilotInfo {

    public record NameAndVersion(String name, String version) implements Serializable {
    }

    private final List<NameAndVersion> versions = new ArrayList<>();

    /** Creates a new instance. */
    public CopilotInfo(ApplicationConfiguration applicationConfiguration) {
        // The order here is the order shown in dev tools
        if (EndpointRequestUtil.isHillaAvailable()) {
            versions.add(new NameAndVersion("Hilla", fetchHillaVersion()));
        }
        versions.add(new NameAndVersion("Flow", Version.getFullVersion()));
        if (isVaadinAvailable()) {
            versions.add(new NameAndVersion("Vaadin", fetchVaadinVersion()));
        }

        if (SpringBridge.isSpringAvailable(applicationConfiguration.getContext())) {
            SpringBridge.VersionInfo springVersions = SpringBridge.getVersionInfo();
            versions.add(new NameAndVersion("Spring Boot", springVersions.springBootVersion()));
            versions.add(new NameAndVersion("Spring", springVersions.springVersion()));
        }

        versions.add(new NameAndVersion("Copilot", CopilotVersion.getVersion()));

        String frontendHotswap = applicationConfiguration.getMode() == Mode.DEVELOPMENT_FRONTEND_LIVERELOAD
                ? "Enabled ⋅ Vite"
                : "Disabled ⋅ Pre-built Bundle";
        versions.add(new NameAndVersion("Frontend Hotswap", frontendHotswap));
        versions.add(new NameAndVersion("OS", fetchOperatingSystem()));
        versions.add(new NameAndVersion("Java", fetchJavaVersion()));
    }

    public static String fetchJavaVersion() {
        String vendor = System.getProperty("java.vendor");
        String version = System.getProperty("java.version");

        return vendor + " " + version;
    }

    public static String fetchOperatingSystem() {
        String arch = System.getProperty("os.arch");
        String name = System.getProperty("os.name");
        String version = System.getProperty("os.version");

        return arch + " " + name + " " + version;
    }

    public static String fetchVaadinVersion() {
        return isVaadinAvailable() ? Platform.getVaadinVersion().orElse("?") : "-";
    }

    public static String fetchHillaVersion() {
        return EndpointRequestUtil.isHillaAvailable() ? Platform.getHillaVersion().orElse("?") : "-";
    }

    public List<NameAndVersion> getVersions() {
        return versions;
    }

    private static boolean isVaadinAvailable() {
        return Thread.currentThread().getContextClassLoader()
                .getResource("META-INF/maven/com.vaadin/vaadin-core/pom.properties") != null;
    }
}
